@@ -526,7 +526,11 @@ ptr_lookup(struct in_addr ip, struct dns_reply *reply)
 	char *name;
 
 	ip.s_addr = ntohl(ip.s_addr);
-	mu_asprintf(&name, "%s.in-addr.arpa", inet_ntoa(ip));
+	mu_asprintf(&name, "%d.%d.%d.%d.in-addr.arpa",
+		    ip.s_addr & 0xff,
+		    (ip.s_addr >> 8) & 0xff,
+		    (ip.s_addr >> 16) & 0xff,
+		    (ip.s_addr >> 24) & 0xff);
 	rc = adns_synchronous(get_state(), name, adns_r_ptr_raw,
 			      DEFAULT_QFLAGS,
 			      &ans);
