@@ -23,7 +23,7 @@ mark_locus(NODE *node, struct mu_locus_range const **old_locus)
                 *old_locus = &node->locus;
 		code_op(opcode_locus);
 		code_immediate(lit->off, ulong);
-		code_immediate(node->locus.beg.mu_line, ulong);
+		code_immediate(node->locus.beg.mu_line, uint);
 	}
 }
 
@@ -2256,7 +2256,7 @@ code_switch_branches(NODE *node, data_type_t type)
 	
 	code_op(opcode_popreg);
 	code_op(type == dtype_number ? opcode_xlat : opcode_xlats);
-	code_immediate(node->v.switch_stmt.tabsize, ulong);
+	code_immediate(node->v.switch_stmt.tabsize, size);
 	code_immediate(data_off, size);
 	code_op(opcode_bnz);
 	code_immediate(1, long);
