@@ -807,6 +807,15 @@ cb_trace_program(void *data, mu_config_value_t *val)
 	return rc;
 }
 
+static int
+cfg_load_relay_file(void *item, void *data)
+{
+	mu_config_value_t *val = item;
+	if (mu_cfg_assert_value_type(val, MU_CFG_STRING) == 0)
+		read_domain_file(val->v.string);
+	return 0;
+}
+
 static int
 cb_relayed_domain_file(void *data, mu_config_value_t *val)
 {
@@ -816,7 +825,7 @@ cb_relayed_domain_file(void *data, mu_config_value_t *val)
 		break;
 
 	case MU_CFG_LIST:
-		mu_list_foreach(val->v.list, load_relay_file, NULL);
+		mu_list_foreach(val->v.list, cfg_load_relay_file, NULL);
 		break;
 
 	default:
