@@ -261,7 +261,7 @@ struct exception_context {
 
 struct environ_locus {
 	unsigned long file;   /* File name */
-	unsigned int line;   /* Line number */
+	unsigned int line;    /* Line number */
 };
 
 struct environ_cleanup_closure {
@@ -942,7 +942,7 @@ pushn(eval_environ_t env, long n)
 void
 instr_locus(eval_environ_t env)
 {
-	env->locus.file = mf_c_val(get_immediate(env, 0), uint);
+	env->locus.file = mf_c_val(get_immediate(env, 0), ulong);
 	env->locus.line = mf_c_val(get_immediate(env, 1), uint);
 	if (PROG_TRACE_ENGINE)
 		prog_trace(env, "LOCUS");
@@ -953,8 +953,8 @@ void
 dump_locus(prog_counter_t i)
 {
 	printf("\"%s\" %lu",
-	       (char*) (dataseg + mf_cell_c_value(prog[i], size)),
-	       (unsigned long) mf_cell_c_value(prog[i+1], size));
+	       (char*) (dataseg + mf_cell_c_value(prog[i], ulong)),
+	       (unsigned long) mf_cell_c_value(prog[i+1], uint));
 }
 
 /* Stack manipulation instructions */
@@ -1968,9 +1968,9 @@ instr_asgn(eval_environ_t env)
 	size_t dest = mf_c_val(get_arg(env, 0), size);
 	adjust_stack(env, 2);
 	if (PROG_TRACE_ENGINE) 
-		prog_trace(env, "ASGN %lu=%u",
+		prog_trace(env, "ASGN %lu=%lu",
 			   (unsigned long) dest,
-			   mf_c_val(val, uint));
+			   mf_c_val(val, ulong));
 	env->dataseg[dest] = val;
 }
 
@@ -1978,7 +1978,7 @@ void
 instr_catch(eval_environ_t env)
 {
 	long off = mf_c_val(get_immediate(env, 0), long);
-	unsigned toff = mf_c_val(get_immediate(env, 1), uint);
+	size_t toff = mf_c_val(get_immediate(env, 1), size);
 	size_t count = mf_c_val(env->dataseg[toff], size);
 	STKVAL *tab = (STKVAL *) (env->dataseg + toff + 1);
 	size_t i;
@@ -2035,8 +2035,8 @@ instr_throw(eval_environ_t env)
 void
 dump_throw(prog_counter_t i)
 {
-	printf("%s (%u)", mf_exception_str(mf_cell_c_value(prog[i], uint)),
-	       mf_cell_c_value(prog[i], uint)); 
+	printf("%s (%lu)", mf_exception_str(mf_cell_c_value(prog[i], ulong)),
+	       mf_cell_c_value(prog[i], ulong)); 
 }
 
 
@@ -2074,13 +2074,14 @@ instr_retcatch(eval_environ_t env)
 void
 instr_saveex(eval_environ_t env)
 {
-	unsigned off = mf_c_val(get_immediate(env, 0), uint);
+	size_t off = mf_c_val(get_immediate(env, 0), size);
 	size_t count = mf_c_val(env->dataseg[off], size);
 	STKVAL *tab = (STKVAL *) (env->dataseg + off + 1);
 	size_t i;
 
 	if (PROG_TRACE_ENGINE)
-		prog_trace(env, "SAVEEX %x (%lu ex.)", off,
+		prog_trace(env, "SAVEEX %lx (%lu ex.)",
+			   (unsigned long) off,
 			   (unsigned long) count);
 
 	advance_pc(env, 1);
@@ -2117,14 +2118,14 @@ dump_saveex(prog_counter_t ctr)
 void
 instr_restex(eval_environ_t env)
 {
-	unsigned off = mf_c_val(pop(env), uint);
+	size_t off = mf_c_val(pop(env), size);
 	size_t count = mf_c_val(env->dataseg[off], size);
 	STKVAL *tab = (STKVAL *) (env->dataseg + off + 1);
 	size_t i;
 	
 	if (PROG_TRACE_ENGINE)
-		prog_trace(env, "RESTEX %x (%lu ex.)",
-			   off, (unsigned long) count);
+		prog_trace(env, "RESTEX %lx (%lu ex.)",
+			   (unsigned long) off, (unsigned long) count);
 	if (!count)
 		return;
 	i = count * NBMBITS - 1;
@@ -2225,14 +2226,15 @@ instr_xlat(eval_environ_t env)
 void
 instr_xlats(eval_environ_t env)
 {
-	unsigned long i;
-	unsigned long count = mf_c_val(get_immediate(env, 0), uint);
+	size_t i;
+	size_t count = mf_c_val(get_immediate(env, 0), size);
 	size_t off = mf_c_val(get_immediate(env, 1), size);
 	STKVAL *tab = (STKVAL *) (env->dataseg + off);
 	char *str = (char*) env_data_ref(env, mf_c_val(env->reg, size));
 	
         if (PROG_TRACE_ENGINE)
-		prog_trace(env, "XLATS %lu %lu", count, (unsigned long) off);
+		prog_trace(env, "XLATS %lu %lu",
+			   (unsigned long) count, (unsigned long) off);
 	advance_pc(env, 2);
 	for (i = 0; i < count; i += 2) {
 		if (strcmp((char*)(env->dataseg + mf_c_val(tab[i], size)), str) == 0) {
@@ -2247,12 +2249,12 @@ instr_xlats(eval_environ_t env)
 void
 dump_xlat(prog_counter_t i)
 {
-	unsigned long j;
-	unsigned long count = mf_cell_c_value(prog[i], ulong);
+	size_t j;
+	size_t count = mf_cell_c_value(prog[i], size);
 	size_t off = mf_cell_c_value(prog[i+1], size);
 	STKVAL *tab = (STKVAL *) (dataseg + off);
 	
-	printf("%lu %lu ", count, (unsigned long) off);
+	printf("%lu %lu ", (unsigned long) count, (unsigned long) off);
 	for (j = 0; j < count; j += 2) 
 		printf("(%ld %ld) ", mf_c_val(tab[j], long), mf_c_val(tab[j+1], long));
 }
