@@ -297,7 +297,7 @@ addq(int argc, char **argv, const char **errp)
 		} else if (!strcasecmp(attr, "mailfrom")) {
 			mailfrom = val;
 		} else {
-			*errp = "unknow attribute";
+			*errp = "unknown attribute";
 			return NULL;
 		}
 	}
